# UI/UX Feedback

**ID:** Feedback-20260222-134734
**URL:** http://127.0.0.1:5858/
**Date:** 2026-02-22 13:48:48

## Selected Elements

- `{'selector': '#wf-create-error', 'parents': ['div.workflow-modal-overlay', 'div.workflow-modal']}`

## Feedback

I found an issue, for creating workflow, and compose the idea, and creating idea folder, it should all support chinese characters or any utf-8 chars

## Screenshot

![Screenshot](x-ipe-docs/uiux-feedback/Feedback-20260222-134734-1/page-screenshot.png)
